from setuptools import setup, find_packages

setup(
    name='monitoring2',
    version='1.1.1',
    packages=find_packages(),
    author='Dmitry Dimonoff',
    author_email='mr.dimonoff@gmail.com',
    url='https://pypi.org/manage/project/monitoring2/release/',
    )